# nonebot-desktop-tk

使用 Tkinter 编写的图形化 NoneBot2 项目管理器。

## 常规安装（未完成）

## 从命令行安装与启动（不推荐）

> 注意：
>
> - Windows 用户请确保
>   - 你使用的 Python 版本为 3.8 或更高；
>
>     > 如果安装了多个版本的 Python，可以通过 `py -3.x`(x >= 8) 在命令行使用指定版本的 Python。
>
>   - 安装 Python 时也安装了 Tkinter 相关组件。
>
>     > Python 官网安装包默认安装，自定义安装需要注意。
>
> - Linux 用户请确保
>   - 你使用的 Python 版本为 3.8 或更高；
>
>     > 如果安装了多个版本的 Python，可以通过 `python3.x`(x >= 8) 在命令行使用指定版本的 Python。
>
>   - 已经通过包管理器等安装了 `tcl` 和 `tk` 这两个包。
>
> 如果要指定 Python 版本，请将下面的 `python` 替换成指定了版本的 Python 程序，
> `pip` 替换成 `{指定了版本的 Python 程序} -m pip`。

```console
# 安装
pip install nonebot-desktop-tk
# 启动
python -m nonebot_desktop_tk
```
